fingers_gesture_detector library
Classes
- FingersGestureDetector
- A gesture detector that tracks multiple finger gestures and provides transformation matrices for translation, scaling, and rotation.
- MatrixDecomposedValues
- Decomposed matrix values
- MatrixUtils
Typedefs
- MatrixUpdateCallback = void Function(Matrix4 matrix, Matrix4 translationDelta, Matrix4 scaleDelta, Matrix4 rotationDelta)
- Callback for matrix updates