FingersGestureDetector class

A gesture detector that tracks multiple finger gestures and provides transformation matrices for translation, scaling, and rotation.

Inheritance

Constructors

FingersGestureDetector({Key? key, required MatrixUpdateCallback onMatrixUpdate, required Widget child, bool shouldTranslate = true, bool shouldScale = true, bool shouldRotate = true, bool clipChild = true, Alignment? focalPointAlignment, HitTestBehavior behavior = HitTestBehavior.deferToChild, double minScale = 0.1, double maxScale = 10.0})
const

Properties

behavior HitTestBehavior
Hit test behavior
final
child Widget
The child widget to detect gestures on
final
clipChild bool
Whether to clip the child widget
final
focalPointAlignment Alignment?
Alignment for the focal point
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxScale double
Maximum scale factor
final
minScale double
Minimum scale factor
final
onMatrixUpdate MatrixUpdateCallback
Called when the transformation matrix updates
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldRotate bool
Whether to detect rotation gestures
final
shouldScale bool
Whether to detect scaling gestures
final
shouldTranslate bool
Whether to detect translation gestures
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FingersGestureDetector>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited