MatrixUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compose(
Matrix4? matrix, Matrix4? translation, Matrix4? scale, Matrix4? rotation) → Matrix4? - Composes multiple transformation matrices
-
rotate(
double angle, Offset focalPoint) → Matrix4 -
Creates a rotation matrix centered at
focalPoint -
scale(
double scale, Offset focalPoint) → Matrix4 -
Creates a scaling matrix centered at
focalPoint -
translate(
Offset translation) → Matrix4 - Creates a translation matrix